@@ -49,6 +49,14 @@ class ExcelDashboarder:
     const_str__config_label__ws_set_column__options__level__as_int: str = "level"
     const_str__config_label__ws_set_column__width__as_float: str = "width"
 
+    const_str__config_label__str_ws_set_row: str = "worksheet.set_row"
+    const_str__config_label__ws_set_row__cell_format__as_dict: str = "cell_format"
+    const_str__config_label__ws_set_row__row__as_int: str = "row"
+    const_str__config_label__ws_set_row__options__as_dict: str = "options"
+    const_str__config_label__ws_set_row__options__hidden__as_int: str = "hidden"
+    const_str__config_label__ws_set_row__options__level__as_int: str = "level"
+    const_str__config_label__ws_set_row__height__as_float: str = "height"
+
     _logger: Logger = getLogger(__name__)
 
     # This is the repository of all the registered widgets:
@@ -447,6 +455,26 @@ class ExcelDashboarder:
                     options=i_set_column.get(self.const_str__config_label__ws_set_column__options__as_dict, None),
                 )
 
+        # for each "worksheet.set_row"
+        if self.const_str__config_label__str_ws_set_row in dict_worksheet_config:
+            for i_set_row in dict_worksheet_config[self.const_str__config_label__str_ws_set_row]:
+
+                # We instantiate the cell format, if any was provided
+                dict_the_format: dict = i_set_row.get(
+                    self.const_str__config_label__ws_set_row__cell_format__as_dict, None
+                )
+                obj_the_format: Optional[Format] = None
+                if dict_the_format is not None:
+                    obj_the_format = wb_workbook.add_format(dict_the_format)
+
+                # We set the row...
+                ws_the_worksheet.set_row(
+                    row=i_set_row[self.const_str__config_label__ws_set_row__row__as_int],
+                    height=i_set_row.get(self.const_str__config_label__ws_set_row__height__as_float, None),
+                    cell_format=obj_the_format,
+                    options=i_set_row.get(self.const_str__config_label__ws_set_row__options__as_dict, None),
+                )
+
         # We check if the sheet is to be hidden
         if dict_worksheet_config.get(self.const_str__config_label__str_worksheet_hide, False):
             ws_the_worksheet.hide()
