@@ -5,7 +5,7 @@ import click
 from click import BadParameter
 
 from com.enovation.toolbox.predictability.bean import PredictabilityBean
-from com.enovation.toolbox.predictability.dp_date_predictability.dp_grapher import DatePredictabilityGrapher
+from com.enovation.toolbox.predictability.dp_date_predictability.dp_grapher.dp_grapher import DpGrapher_DashApplication
 
 _logger: logging.Logger = logging.getLogger(__name__)
 
@@ -34,6 +34,6 @@ def dp_graph_to_dash_date_predictability(ctx_context, alias):
 
     obj_the_data: PredictabilityBean = ctx_context.obj[alias]
 
-    DatePredictabilityGrapher().graph_predictability(obj_predictability=obj_the_data)
+    DpGrapher_DashApplication(obj_predictability=obj_the_data).graph_predictability()
 
-    _logger.debug(f"Function '{stack()[0].filename} - {stack()[0].function}' is returning")
\ No newline at end of file
+    _logger.debug(f"Function '{stack()[0].filename} - {stack()[0].function}' is returning")
