@@ -58,7 +58,8 @@ class DatePredictabilityComputer:
     def compute_historical_date_predictability(
             self,
             df_measures: DataFrame,
-            b_resample: bool = True
+            b_resample: bool = True,
+            int_sliding_window: int = None
     ) -> PredictabilityBean:
         """
         Function to compute date predictability for a set of measures provided as parameter.
@@ -92,13 +93,19 @@ class DatePredictabilityComputer:
                 - With convergence_cone defined by:
                     - Upper limit: date + abs(date - last_measure)
                     - Lower limit: date - abs(date - last_measure)
-        - If b_resample == True:
+        - If b_resample == False:
             - The logic is more optimal than when sampling, but graphing the historical trend of the
               date_predictability is far less meaningful, and even misleading
             - The date predictability is computed as:
                 - For each measure that spans from its date until the next one, we compute date_predictability as
                     - SUM for_each_day (spot_predictabilty) with spot_predictability as defined above
 
+        Regarding parameter int_sliding_window:
+        - It can only be provided when b_resample is equal to True, or an exception is thrown
+        - It set the length in days of the sliding window that filters historical measures: only measures within
+          this sliding window are considered, the older ones are ignored
+        - By default, all historical measures are considered, even the oldest ones
+
         :param df_measures: a dataframe that contains the measures
         :param b_resample: whether or not we want to resample daily the measures, for later graphing
         :return: the date predictability for the measures provided as a parameter
@@ -123,6 +130,15 @@ class DatePredictabilityComputer:
             str_column_label_measure=self.str__input__column_label__measure,
         )
 
+        # 2b. We check if a sliding window is set, that b_sample is true
+        if (
+            (int_sliding_window is not None)
+            & (b_resample is False)
+        ):
+            raise Exception(f"Function '{stack()[0].filename} - {stack()[0].function}' is not properly called: "
+                            f"parameter int_sliding_window is not null, equalt to '{int_sliding_window}', while"
+                            f"parameter b_sample is '{b_resample}'.")
+
         # 3. Depending on whether or not we need to resample, we call the function to compute historical predictability
         if b_resample:
             df_the_historical_predictability: DataFrame = self._resample_and_compute_historical_date_predictability(
@@ -132,6 +148,7 @@ class DatePredictabilityComputer:
                 str_column_label__measure=self.str__input__column_label__measure,
                 str_column_label__predictability=self.str__output__column_label__predictability,
                 str_resample_rule=self._str__default_resampling_rule,
+                int_sliding_window=int_sliding_window
             )
         else:
             df_the_historical_predictability: DataFrame = \
@@ -145,7 +162,7 @@ class DatePredictabilityComputer:
                 )
 
         # 4. We compute the statistics
-        df_the_statistics_by_key: DataFrame = self._compute_statistics_by_key(
+        df_the_statistics_by_key: DataFrame = self.compute_statistics_by_key(
             df_measures=the_df_typed.copy(),
             df_historical_predictability=df_the_historical_predictability,
             str_column_label__key=self.str__input__column_label__key,
@@ -332,6 +349,7 @@ class DatePredictabilityComputer:
             str_column_label__measure: str = str__input__column_label__measure,
             str_column_label__predictability: str = str__output__column_label__predictability,
             str_resample_rule: str = _str__default_resampling_rule,
+            int_sliding_window: int = None
     ) -> DataFrame:
 
         # 1. We resample
@@ -350,7 +368,8 @@ class DatePredictabilityComputer:
                 str_column_label__key=str_column_label_key,
                 str_column_label__date=str_column_label_date,
                 str_column_label__measure=str_column_label__measure,
-                str_column_label__predictability=str_column_label__predictability
+                str_column_label__predictability=str_column_label__predictability,
+                int_sliding_window=int_sliding_window
             )
 
         self._logger.debug(f"Function '{stack()[0].filename} - {stack()[0].function}' is returning")
@@ -385,34 +404,20 @@ class DatePredictabilityComputer:
             str_column_label__key: str = str__input__column_label__key,
             str_column_label__date: str = str__input__column_label__date,
             str_column_label__measure: str = str__input__column_label__measure,
-            str_column_label__predictability: str = str__output__column_label__predictability
+            str_column_label__predictability: str = str__output__column_label__predictability,
+            int_sliding_window: int = None
     ) -> DataFrame:
         """
         A function to compute a date predictability across history.
 
         :param df_measures: measures for a given key
+        :param int_sliding_window: the length in days of the sliding window to compute predictability. Old measures
+          that falls outside this sliding window are ignored. By default, this filter is ignored, and all
+          historical data, ever the oldest ones, are considered.
         :return: the historical predictability that would have been computed as of the last date.
         """
         self._logger.debug(f"Function '{stack()[0].filename} - {stack()[0].function}' is called.")
 
-        # The expanding does not seem to work, raising an exception we did not succeed to fix:
-        # "pandas.core.base.DataError: No numeric types to aggregate"
-        # To workaround, we implement a loop...
-        #
-        # df_the_return: DataFrame = df_measures \
-        #     .sort_values(by=[
-        #         str_column_label__key,
-        #         str_column_label__date
-        #     ]) \
-        #     .reset_index(drop=True)
-        #
-        # df_the_return[str_column_label__predictability] = df_the_return\
-        #     .groupby(str_column_label__key)\
-        #     .expanding(engine='numba', method='table')\
-        #     .agg(
-        #         self._compute_spot_predictability_for_a_given_key
-        #     )
-
         df_measures[str_column_label__predictability] = -1
 
         # Setup progress bar
@@ -428,11 +433,25 @@ class DatePredictabilityComputer:
             # We compute the predictability:
             # - For the given key
             # - For all the previous records at the date
+
+            # We filter the past measures for a given key
+            df_the_filtered_measures: DataFrame = df_measures[
+                (df_measures[str_column_label__key] == getattr(t_i_row, str_column_label__key))
+                & (df_measures[str_column_label__date] <= getattr(t_i_row, str_column_label__date))
+            ]
+
+            # If the sliding window is defined
+            if int_sliding_window is not None:
+                df_the_filtered_measures = df_the_filtered_measures[
+                    df_measures[str_column_label__date] >= (
+                        getattr(t_i_row, str_column_label__date) -
+                        timedelta(days=int_sliding_window)
+                    )
+                ]
+
+            # Eventually, we call the function to compute the data predictability for the key and date
             f_i_predictability = self._compute_date_predictability_for_a_given_key_and_resampled_measures(
-                df_measures=df_measures[
-                    (df_measures[str_column_label__key] == getattr(t_i_row, str_column_label__key))
-                    & (df_measures[str_column_label__date] <= getattr(t_i_row, str_column_label__date))
-                    ],
+                df_measures=df_the_filtered_measures,
                 str_column_label__date=str_column_label__date,
                 str_column_label__measure=str_column_label__measure,
             )
@@ -451,7 +470,7 @@ class DatePredictabilityComputer:
             self,
             df_measures: DataFrame,
             str_column_label__date: str = str__input__column_label__date,
-            str_column_label__measure: str = str__input__column_label__measure,
+            str_column_label__measure: str = str__input__column_label__measure
     ) -> float:
         # Too many logs:
         # self._logger.debug(f"Function '{stack()[0].filename} - {stack()[0].function}' is called.")
@@ -490,7 +509,7 @@ class DatePredictabilityComputer:
             )
         )
 
-        # The last measure should not contribute tot he aggregated predictability
+        # The last measure should not contribute to the aggregated predictability
         # Therefore, we remove the last record from the ndarray (only if more than 1 records)
         if len(a_measures_predictabilities) > 1:
             a_measures_predictabilities = a_measures_predictabilities[:-1]
@@ -656,7 +675,7 @@ class DatePredictabilityComputer:
 
         return f_the_return
 
-    def _compute_statistics_by_key(
+    def compute_statistics_by_key(
             self,
             df_measures: DataFrame,
             df_historical_predictability: DataFrame,
@@ -679,10 +698,24 @@ class DatePredictabilityComputer:
         """
         todo.
 
+        :param str_column_label__predictability_last:
+        :param str_column_label__measure_max:
+        :param str_column_label__measure_min:
+        :param str_column_label__measure_last:
+        :param str_column_label__measure_first:
+        :param str_column_label__date_last:
+        :param str_column_label__date_first:
+        :param str_column_label__measure_count:
+        :param str_column_label__predictability:
+        :param str_column_label__measure:
+        :param str_column_label__date:
+        :param str_column_label__key:
+        :param df_measures:
         :param df_historical_predictability: measures for a given key
         :return: the historical predictability that would have been computed as of the last date.
         """
-        self._logger.debug(f"Function '{stack()[0].filename} - {stack()[0].function}' is called.")
+
+        self._logger.debug(f"Function '{stack()[0].filename} - {stack()[0].function}' is called")
 
         # 1. We compute global statistics for each predictability.V2.V2 key:
         #       - date_first
@@ -741,6 +774,6 @@ class DatePredictabilityComputer:
             how="left"
         )
 
-        self._logger.debug(f"Function '{stack()[0].filename} - {stack()[0].function}' is returning.")
+        self._logger.debug(f"Function '{stack()[0].filename} - {stack()[0].function}' is returning")
 
         return df_the_stats_by_key
